%define anolis_release 1
%global _hardened_build 1

Summary: IPMI (Intelligent Platform Management Interface) library and tools
Name: OpenIPMI

Version:    2.0.32
Release:    %{anolis_release}%{?dist}
License:    LGPLv2+ and GPLv2+ or BSD
URL:        http://sourceforge.net/projects/openipmi/
Source:     http://downloads.sourceforge.net/openipmi/%{name}-%{version}.tar.gz
Source1:    openipmi.sysconf
Source2:    openipmi-helper
Source3:    ipmi.service
Patch1:     0001-man.patch
Patch2:     OpenIPMI-ax-python.patch
Patch3:     OpenIPMI-sysconfig.patch

BuildRequires: make
BuildRequires:    gdbm-devel swig glib2-devel net-snmp-devel ncurses-devel
BuildRequires:    openssl-devel python3-devel perl-devel perl-generators
BuildRequires:    pkgconfig
BuildRequires:    readline-devel
BuildRequires:    automake
BuildRequires:    autoconf
BuildRequires:    libtool
%{?systemd_requires}
BuildRequires:    systemd

Requires:         %{name}-libs = %{version}-%{release}

# Prevent bogus provides of private libs from perl
%global __provides_exclude_from %{?__provides_exclude_from:%{__provides_exclude_from}|}^%{perl_vendorarch}/auto/.*\\.so$

%description
The Open IPMI project aims to develop an open code base to allow access to
platform information using Intelligent Platform Management Interface (IPMI).
This package contains the tools of the OpenIPMI project.

%package libs
Summary: The OpenIPMI runtime libraries

%description libs
The OpenIPMI-libs package contains the runtime libraries for shared binaries
and applications.

%package perl
Summary:  IPMI Perl language bindings
Requires: %{name}-libs = %{version}-%{release}

%description perl
The OpenIPMI-perl package contains the Perl language bindings for OpenIPMI.

%package -n python3-openipmi
Provides:  python3-OpenIPMI = %{version}-%{release}
Provides:  %{name}-python = %{version}-%{release}
Provides:  %{name}-python = %{version}-%{release}
Summary:   IPMI Python language bindings
Requires:  %{name}-libs = %{version}-%{release}

%description -n python3-openipmi
The OpenIPMI-python package contains the Python language bindings for OpenIPMI.

%package devel
Summary:  The development environment for the OpenIPMI project
Requires: pkgconfig
Requires: %{name} = %{version}-%{release}
Requires: %{name}-libs = %{version}-%{release}

%description devel
The OpenIPMI-devel package contains the development libraries and header files
of the OpenIPMI project.

%package lanserv
Summary:  Emulates an IPMI network listener
Requires: %{name} = %{version}-%{release}

%description lanserv
This package contains a network IPMI listener.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1

%build

%configure \
    CFLAGS="-fPIC %{optflags} -z now -fno-strict-aliasing" \
    LDFLAGS="%{__global_ldflags} -Wl,--as-needed" \
    --disable-dependency-tracking \
    --disable-static \
    --with-pythoninstall=%{python3_sitearch} \
    --with-python=%{__python3} \
    --with-tcl=no \
    --with-tkinter=no

sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

make   # not %%{?_smp_mflags} safe

%install
make install DESTDIR=%{buildroot}

install -d %{buildroot}{%{_sysconfdir}/sysconfig,%{_unitdir},%{_libexecdir}}
install -m 644 %SOURCE1 %{buildroot}%{_sysconfdir}/sysconfig/ipmi
install -m 755 %SOURCE2 %{buildroot}%{_libexecdir}/openipmi-helper
install -m 644 %SOURCE3 %{buildroot}%{_unitdir}/ipmi.service
install -d %{buildroot}%{_sysconfdir}/modprobe.d

rm %{buildroot}/%{_mandir}/man1/openipmigui.1 %{buildroot}%{_libdir}/*.la

# add missing documentation 
echo ".so man1/openipmicmd.1" > %{buildroot}%{_mandir}/man1/ipmicmd.1

echo ".so man1/openipmish.1" > %{buildroot}%{_mandir}/man1/ipmish.1

%generate_compatibility_deps

%post
%systemd_post ipmi.service

%preun
%systemd_preun ipmi.service

%postun
%systemd_postun_with_restart ipmi.service

%triggerun -- OpenIPMI < 2.0.18-14
# Save the current service runlevel info
# User must manually run systemd-sysv-convert --apply httpd
# to migrate them to systemd targets
/usr/bin/systemd-sysv-convert --save ipmi >/dev/null 2>&1 ||:
/bin/systemctl --no-reload enable ipmi.service >/dev/null 2>&1 ||:
# Run these because the SysV package being removed won't do them
/sbin/chkconfig --del ipmi >/dev/null 2>&1 || :
/bin/systemctl try-restart ipmi.service >/dev/null 2>&1 || :

%files
%license COPYING COPYING.BSD COPYING.LIB
%config(noreplace) %{_sysconfdir}/sysconfig/ipmi
%{_libexecdir}/openipmi-helper
%{_bindir}/ipmicmd
%{_bindir}/ipmish
%{_bindir}/ipmi_ui
%{_bindir}/openipmicmd
%{_bindir}/openipmish
%{_bindir}/rmcp_ping
%{_bindir}/solterm
%{_bindir}/openipmi_eventd
%{_unitdir}/ipmi.service
%{_mandir}/man1/ipmi_ui*
%{_mandir}/man1/openipmicmd*
%{_mandir}/man1/openipmish*
%{_mandir}/man1/rmcp_ping*
%{_mandir}/man1/solterm*
%{_mandir}/man1/ipmish*
%{_mandir}/man1/ipmicmd*
%{_mandir}/man1/openipmi_eventd*
%{_mandir}/man7/ipmi_cmdlang*
%{_mandir}/man7/openipmi_conparms*
%{abidir}/openipmish-option.list
%{abidir}/rmcp_ping-option.list

%files perl
%attr(644,root,root) %{perl_vendorarch}/OpenIPMI.pm
%{perl_vendorarch}/auto/OpenIPMI

%files -n python3-openipmi
%{python3_sitearch}/*OpenIPMI*
%{python3_sitearch}/__pycache__/OpenIPMI.*.pyc
%{abidir}/OpenIPMI.dump
%{abidir}/_OpenIPMI.dump

%files libs
%{_libdir}/libOpenIPMI*.so.*
%dir %{abidir}
%{abidir}/libOpenIPMI.dump
%{abidir}/libOpenIPMIcmdlang.dump
%{abidir}/libOpenIPMIglib.dump
%{abidir}/libOpenIPMIposix.dump
%{abidir}/libOpenIPMIpthread.dump
%{abidir}/libOpenIPMIui.dump
%{abidir}/libOpenIPMIutils.dump

%files devel
%{_includedir}/OpenIPMI
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%files lanserv
%config(noreplace) %{_sysconfdir}/ipmi/ipmisim1.emu
%config(noreplace) %{_sysconfdir}/ipmi/lan.conf
%dir %{_sysconfdir}/ipmi
%{_bindir}/ipmilan
%{_bindir}/ipmi_sim
%{_bindir}/sdrcomp
%{_libdir}/libIPMIlanserv.so.*
%{_mandir}/man8/ipmilan.8*
%{_mandir}/man1/ipmi_sim.1*
%{_mandir}/man5/ipmi_lan.5*
%{_mandir}/man5/ipmi_sim_cmd.5*
%{abidir}/libIPMIlanserv.dump
%{abidir}/ipmilan-option.list
%{abidir}/ipmi_sim-option.list


%files doc
%doc CONFIGURING_FOR_LAN FAQ README README.Force README.MotorolaMXP

%changelog
* Tue Mar 28 2023 happy_orange <songnannan@linux.alibaba.com> - 2.0.32-1
- init package
